=====================
GANGA GUI User Manual
=====================

:Author:        Chun Lik Tan (clat@hep.ph.bham.ac.uk)
:Instituition:  University of Birmingham
:Version:       1.1.x
:Ganga Version: 4.1.x
:Modified:      9 March 2006
:Bugs:          Report bugs to Savannah_
:Website:       http://ganga.web.cern.ch


- Introduction_
- `Quick Start`_
- `Getting around`_
   - Menubar_
   - Toolbar_
   - Monitoring_
   - `Job Builder`_
      - Templates_
      - Splitters_
   - Scriptor_
   - Log_
- Examples_
   - `Generic job`_
   - `ATLAS job`_
   - `LHCb job`_
- `GUI Customisation`_
   - `General configurations`_
      - `File associations`_
      - `Invoking external applications`_
   - `Monitoring configurations`_
      - `Status colour schema`_
   - `Job Builder configurations`_
   - `Scriptor configurations`_
   - `Log configurations`_
   - `Logical Folder configurations`_
- FAQ_


.. _Introduction: gangagui-manual-chapter_1.html
.. _`Quick Start`: gangagui-manual-chapter_2.html
.. _`Getting around`: gangagui-manual-chapter_3.html
.. _Menubar: gangagui-manual-chapter_3.html#menubar
.. _Toolbar: gangagui-manual-chapter_3.html#toolbar
.. _Monitoring: gangagui-manual-chapter_3.html#monitoring
.. _`Job Builder`: gangagui-manual-chapter_3.html#job-builder
.. _Templates: gangagui-manual-chapter_3.html#templates
.. _Splitters: gangagui-manual-chapter_3.html#splitters
.. _Scriptor: gangagui-manual-chapter_3.html#scriptor
.. _Log: gangagui-manual-chapter_3.html#log
.. _Examples: gangagui-manual-chapter_4.html
.. _`Generic job`: gangagui-manual-chapter_4.html#generic-job
.. _`ATLAS job`: gangagui-manual-chapter_4.html#atlas-job
.. _`LHCb job`: gangagui-manual-chapter_4.html#lhcb-job
.. _`GUI Customisation`: gangagui-manual-chapter_5.html
.. _`General configurations`: gangagui-manual-chapter_5.html#general-configurations
.. _`File associations`: gangagui-manual-chapter_5.html#file-associations
.. _`Invoking external applications`: gangagui-manual-chapter_5.html#invoking-external-applications
.. _`Monitoring configurations`: gangagui-manual-chapter_5.html#monitoring-configurations
.. _`Status colour schema`: gangagui-manual-chapter_5.html#status-colour-schema
.. _`Job Builder configurations`: gangagui-manual-chapter_5.html#job-builder-configurations
.. _`Scriptor configurations`: gangagui-manual-chapter_5.html#scriptor-configurations
.. _`Log configurations`: gangagui-manual-chapter_5.html#log-configurations
.. _`Logical Folder configurations`: gangagui-manual-chapter_5.html#logical-folder-configurations
.. _FAQ: gangagui-manual-chapter_6.html
.. _Savannah:     https://savannah.cern.ch/bugs/?func=additem&group=ganga
